
##### TP de Gntique Quantitative: estimation de l'hritabilit d'un caractre  partir de donnes familiales #####

### Exploration prliminaire des donnes ###
## Ouvrir le fichier "pheno_pedigree.txt" 
data=read.table("pheno_pedigree.txt",header=TRUE)
names(data)
dim(data)

## informations sur les individu/familles
length(data$individual)			# 1853 individus
length(table(data$family))		# 162 familles
length(table(data$father))		# 162 pres
length(table(data$mother))		# 162 mres
hist(table(data$family),20)		# distribution du nombre de plein-frres sur l'ensemble des familles
mean(table(data$family))		# nombre moyen de pleins-frres par famille

## informations sur les caractres
summary();var();sd()
summary();var();sd()

par(mfrow=c(1,3))
hist(,main="poids (kg/m3)")
hist(,main="hauteur (m)")
plot(,,pch=16)
cor(,)


## correction des donnes phnotypiques par le facteur sexe
data$weight_corr= resid(lm(data$weight ~ 0+as.factor(data$sex)))
data$height_corr= resid(lm(data$height ~ 0+as.factor(data$sex)))

### Estimation de l'hritabilit et influence de l'chantillonnage sur la prcision de l'estimation ###

# La boucle qui suit permet de calculer la covariance "frre vs frre" en chantillonnant des paires de frres
# dans toutes les familles et en calculant la covariance entre les deux vecteurs de valeurs
# la procdure peut tre rptes, ce qui permet d'avoir une ide de la prcision de l'estimation de l'hritabilit
#######################################################################################################


# the list of families is
listfam=names(table(data$family))

#how many families? 
nfam=length(listfam)

# We can repeat this a few times !!
# subset() : Return subsets of vectors, matrices or data frames which meet conditions. 
# sample() : takes a sample of the specified size from the elements of x, without replacement (replace = FALSE). 


h2=NA
for (ii in 1:1){

        # prepare two vectors, the i'th case contains the weights of two animals from the same family
        # then we can compute the covariance of vector 1 with vector 2 and find out the genetic covariance
        vec1=rep(NA,nfam)
        vec2=rep(NA,nfam)

        # do a loop picking two animals by family
        pos=0
        for (i in listfam){
                pos=pos+1
                aux=subset(data,family==i)
                # if the family has more than one member
                if(nrow(aux)>1){
			aux2=sample(aux$weight_corr,2,replace = F)  
			#aux2=sample(aux$height_corr,2,replace = F)
			vec1[pos]=aux2[1]; vec2[pos]=aux2[2]
                }
        }
      
        # THE COVARIANCE (between this 2 vectors of full-sibs) is:
        cov_P= cov(vec1,vec2,use="complete.obs")

        # THE ADDITIVE GENETIC VARIANCE is the covariance (cov_P) / additive relationship (a(i,j)) 
        # coefficient de parent phi(i,j) pour des plein frres/soeurs est de 0.25 ==> a(i,j) = 2*phi(i,j)=2*0.25=0.5
        var_A=cov_P/0.5

        # TOTAL PHENOTYPIC VARIANCE IS:
		var_P=var(data$weight)
		#var_P=var(data$height)
		  
        # and HERITABILITY:
        h2[ii]=var_A/var_P
		
        cat("heritabilit", h2[ii],ii,"\n")
}



